@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 # StarPU --- Runtime system for heterogeneous multicore architectures.
 #
 # Copyright (C) 2012-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
@@ -36,9 +36,32 @@ else
 	SCHEDULERS=`$basedir/../../tools/starpu_sched_display | grep -v pheft | grep -v peager | grep -v heteroprio | grep -v modular-gemm`
 fi
 
-for sched in $SCHEDULERS
-do
+run()
+{
+    sched=$1
     echo "sched_ctx.$sched"
-    STARPU_SCHED=$sched $STARPU_LAUNCH $basedir/../sched_ctx/sched_ctx
+    STARPU_SCHED=$sched $STARPU_SUB_PARALLEL $STARPU_LAUNCH $basedir/../sched_ctx/sched_ctx
     check_success $?
-done
+}
+
+if [ -n "$STARPU_SUB_PARALLEL" ]
+then
+	for sched in $SCHEDULERS
+	do
+		run $sched &
+	done
+	RESULT=0
+	while true
+	do
+		wait -n
+		RET=$?
+		if [ $RET = 127 ] ; then break ; fi
+		if [ $RET != 0 -a $RET != 77 ] ; then RESULT=1 ; fi
+	done
+	exit $RESULT
+else
+	for sched in $SCHEDULERS
+	do
+		run $sched
+	done
+fi
