@@ -1,9 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2013                                Inria
- * Copyright (C) 2010-2013,2015,2017                      CNRS
- * Copyright (C) 2009-2011,2013-2015                      Université de Bordeaux
- * Copyright (C) 2010                                     Mehdi Juhoor
+ * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010       Mehdi Juhoor
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -48,45 +46,10 @@ static void parse_args(int argc, char **argv)
 	}
 }
 
-/* This filter function takes a CSR matrix, and divides it into nparts with the
- * same number of rows. */
-static void csr_filter_func(void *father_interface, void *child_interface, struct starpu_data_filter *f, unsigned id, unsigned nparts)
-{
-	struct starpu_csr_interface *csr_father = (struct starpu_csr_interface *) father_interface;
-	struct starpu_csr_interface *csr_child = (struct starpu_csr_interface *) child_interface;
-
-	uint32_t nrow = csr_father->nrow;
-	size_t elemsize = csr_father->elemsize;
-	uint32_t firstentry = csr_father->firstentry;
-
-	/* Every sub-parts should contain the same number of non-zero entries */
-	uint32_t chunk_size = (nrow + nparts - 1)/nparts;
-	uint32_t *rowptr = csr_father->rowptr;
-
-	uint32_t first_index = id*chunk_size - firstentry;
-	uint32_t local_firstentry = rowptr[first_index];
-
-	uint32_t child_nrow = STARPU_MIN(chunk_size, nrow - id*chunk_size);
-	uint32_t local_nnz = rowptr[first_index + child_nrow] - rowptr[first_index];
-
-	csr_child->id = csr_father->id;
-	csr_child->nnz = local_nnz;
-	csr_child->nrow = child_nrow;
-	csr_child->firstentry = local_firstentry;
-	csr_child->elemsize = elemsize;
-
-	if (csr_father->nzval)
-	{
-		csr_child->rowptr = &csr_father->rowptr[first_index];
-		csr_child->colind = &csr_father->colind[local_firstentry];
-		csr_child->nzval = csr_father->nzval + local_firstentry * elemsize;
-	}
-}
-
 /* partition the CSR matrix along a block distribution */
 static struct starpu_data_filter csr_f =
 {
-	.filter_func = csr_filter_func,
+	.filter_func = starpu_csr_filter_vertical_block,
 	/* This value is defined later on */
 	.nchildren = -1,
 	/* the children also use a csr interface */
@@ -135,6 +98,7 @@ int main(int argc, char **argv)
 	/* Input and Output vectors */
 	float *vector_in_ptr;
 	float *vector_out_ptr;
+	float *vector_exp_out_ptr;
 
 	/*
 	 *	Parse command-line arguments
@@ -158,6 +122,9 @@ int main(int argc, char **argv)
 	starpu_malloc((void **)&rowptr, (size+1)*sizeof(uint32_t));
 	assert(nzval && colind && rowptr);
 
+#define UPPER_BAND 1.
+#define MIDDLE_BAND 5.
+#define LOWER_BAND 1.
 	/* fill the matrix */
 	for (row = 0, pos = 0; row < size; row++)
 	{
@@ -165,18 +132,18 @@ int main(int argc, char **argv)
 
 		if (row > 0)
 		{
-			nzval[pos] = 1.0f;
+			nzval[pos] = LOWER_BAND;
 			colind[pos] = row-1;
 			pos++;
 		}
 		
-		nzval[pos] = 5.0f;
+		nzval[pos] = MIDDLE_BAND;
 		colind[pos] = row;
 		pos++;
 
 		if (row < size - 1)
 		{
-			nzval[pos] = 1.0f;
+			nzval[pos] = UPPER_BAND;
 			colind[pos] = row+1;
 			pos++;
 		}
@@ -189,12 +156,13 @@ int main(int argc, char **argv)
 	/* initiate the 2 vectors */
 	starpu_malloc((void **)&vector_in_ptr, size*sizeof(float));
 	starpu_malloc((void **)&vector_out_ptr, size*sizeof(float));
-	assert(vector_in_ptr && vector_out_ptr);
+	starpu_malloc((void **)&vector_exp_out_ptr, size*sizeof(float));
+	assert(vector_in_ptr && vector_out_ptr && vector_exp_out_ptr);
 
 	/* fill them */
 	for (ind = 0; ind < size; ind++)
 	{
-		vector_in_ptr[ind] = 2.0f;
+		vector_in_ptr[ind] = ind % 100;
 		vector_out_ptr[ind] = 0.0f;
 	}
 
@@ -266,11 +234,31 @@ int main(int argc, char **argv)
                 FPRINTF(stdout, "%2.2f\t%2.2f\n", vector_in_ptr[row], vector_out_ptr[row]);
 	}
 
+	/* Check the result */
+	memset(vector_exp_out_ptr, 0, sizeof(vector_exp_out_ptr[0])*size);
+	for (row = 0; row < size; row++)
+	{
+		if (row > 0)
+			vector_exp_out_ptr[row] += LOWER_BAND * vector_in_ptr[row-1];
+		vector_exp_out_ptr[row] += MIDDLE_BAND * vector_in_ptr[row];
+		if (row < size-1)
+			vector_exp_out_ptr[row] += UPPER_BAND * vector_in_ptr[row+1];
+	}
+	for (row = 0; row < size; row++)
+	{
+		if (vector_out_ptr[row] != vector_exp_out_ptr[row])
+		{
+			FPRINTF(stderr, "check failed at %u: %f vs expected %f\n", row, vector_out_ptr[row], vector_exp_out_ptr[row]);
+			exit(EXIT_FAILURE);
+		}
+	}
+
 	starpu_free(nzval);
 	starpu_free(colind);
 	starpu_free(rowptr);
 	starpu_free(vector_in_ptr);
 	starpu_free(vector_out_ptr);
+	starpu_free(vector_exp_out_ptr);
 
 	/*
 	 *	Stop StarPU
