@@ -334,17 +334,17 @@ void update_func_cpu(void *descr[], void *arg)
 {
 	struct block_description *block = (struct block_description *) arg;
 	int workerid = starpu_worker_get_id_check();
-	DEBUG( "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
+	DEBUG( "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
 	if (block->bz == 0)
-		FPRINTF(stderr,"!!! DO update_func_cpu z %u CPU%d !!!\n", block->bz, workerid);
+		FPRINTF(stderr,"!!! DO update_func_cpu z %u worker%d !!!\n", block->bz, workerid);
 	else
-		DEBUG( "!!! DO update_func_cpu z %u CPU%d !!!\n", block->bz, workerid);
+		DEBUG( "!!! DO update_func_cpu z %u worker%d !!!\n", block->bz, workerid);
 #if defined(STARPU_USE_MPI) && !defined(STARPU_SIMGRID) && !defined(STARPU_USE_MPI_MASTER_SLAVE)
 	int rank = 0;
 	MPI_Comm_rank(MPI_COMM_WORLD, &rank);
-	DEBUG( "!!!           RANK %d            !!!\n", rank);
+	DEBUG( "!!!            RANK %d              !!!\n", rank);
 #endif
-	DEBUG( "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
+	DEBUG( "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!\n");
 
 	unsigned block_size_z = get_block_size(block->bz);
 	unsigned i;
