@@ -842,16 +842,19 @@ static void _starpu_mpi_handle_request_termination(struct _starpu_mpi_req *req)
 	{
 		if (req->request_type == RECV_REQ || req->request_type == SEND_REQ)
 		{
+			if (req->request_type == SEND_REQ)
+			{
+				// We need to make sure the communication for sending the size
+				// has completed, as MPI can re-order messages, let's call
+				// MPI_Wait to make sure data have been sent
+				int ret;
+				ret = MPI_Wait(&req->backend->size_req, MPI_STATUS_IGNORE);
+				STARPU_MPI_ASSERT_MSG(ret == MPI_SUCCESS, "MPI_Wait returning %s", _starpu_mpi_get_mpi_error_code(ret));
+			}
 			if (req->registered_datatype == 0)
 			{
 				if (req->request_type == SEND_REQ)
 				{
-					// We need to make sure the communication for sending the size
-					// has completed, as MPI can re-order messages, let's call
-					// MPI_Wait to make sure data have been sent
-					int ret;
-					ret = MPI_Wait(&req->backend->size_req, MPI_STATUS_IGNORE);
-					STARPU_MPI_ASSERT_MSG(ret == MPI_SUCCESS, "MPI_Wait returning %s", _starpu_mpi_get_mpi_error_code(ret));
 					starpu_free_on_node_flags(STARPU_MAIN_RAM, (uintptr_t)req->ptr, req->count, 0);
 					req->ptr = NULL;
 				}
@@ -1193,10 +1196,14 @@ static void *_starpu_mpi_progress_thread_func(void *arg)
 		argv_cpy[i] = strdup((*(argc_argv->argv))[i]);
 	void **tsd;
 	_STARPU_CALLOC(tsd, MAX_TSD + 1, sizeof(void*));
-#ifdef HAVE_SG_ACTOR_DATA
+#if defined(HAVE_SG_ACTOR_DATA) || defined(HAVE_SG_ACTOR_SET_DATA)
 	_starpu_simgrid_actor_create("main", smpi_simulated_main_, _starpu_simgrid_get_host_by_name("MAIN"), *(argc_argv->argc), argv_cpy);
 	/* And set TSD for us */
+#ifdef HAVE_SG_ACTOR_SET_DATA
+	sg_actor_set_data(sg_actor_self(), tsd);
+#else
 	sg_actor_data_set(sg_actor_self(), tsd);
+#endif
 #else
 	MSG_process_create_with_arguments("main", smpi_simulated_main_, NULL, _starpu_simgrid_get_host_by_name("MAIN"), *(argc_argv->argc), argv_cpy);
 	/* And set TSD for us */
