@@ -40,7 +40,7 @@ int main(int argc, char **argv)
 		starpu_mpi_shutdown();
 		if (!mpi_init)
 			MPI_Finalize();
-		return STARPU_TEST_SKIPPED;
+		return rank == 0 ? STARPU_TEST_SKIPPED : 0;
 	}
 
 	for(i=0 ; i<4 ; i++)
@@ -127,5 +127,5 @@ int main(int argc, char **argv)
 	if (!mpi_init)
 		MPI_Finalize();
 
-	return ret;
+	return rank == 0 ? ret : 0;
 }
