@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2012                                Inria
- * Copyright (C) 2012,2015,2017                           CNRS
- * Copyright (C) 2010-2011, 2018                                Université de Bordeaux
+ * Copyright (C) 2010-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -29,24 +27,24 @@ soclGetPlatformIDs(cl_uint          num_entries,
 		   cl_platform_id * platforms,
 		   cl_uint *        num_platforms)
 {
-     if (_starpu_init_failed)
-     {
-	  if (num_platforms != NULL)
-	       *num_platforms = 0;
-	  return CL_SUCCESS;
-     }
+	if (_starpu_init_failed)
+	{
+		if (num_platforms != NULL)
+			*num_platforms = 0;
+		return CL_SUCCESS;
+	}
 
-     if ((num_entries == 0 && platforms != NULL)
-	 || (num_platforms == NULL && platforms == NULL))
-	  return CL_INVALID_VALUE;
+	if ((num_entries == 0 && platforms != NULL)
+	    || (num_platforms == NULL && platforms == NULL))
+		return CL_INVALID_VALUE;
+	else
+	{
+		if (platforms != NULL)
+			platforms[0] = &socl_platform;
 
-     else {
-	  if (platforms != NULL)
-	       platforms[0] = &socl_platform;
+		if (num_platforms != NULL)
+			*num_platforms = 1;
+	}
 
-	  if (num_platforms != NULL)
-	       *num_platforms = 1;
-     }
-
-   return CL_SUCCESS;
+	return CL_SUCCESS;
 }
