@@ -55,7 +55,7 @@
 #define MAX_OPEN_FILES 64
 #define TEMP_HIERARCHY_DEPTH 2
 
-#if !defined(HAVE_COPY_FILE_RANGE) && defined( __NR_copy_file_range)
+#if !defined(HAVE_COPY_FILE_RANGE) && defined(__linux__) && defined( __NR_copy_file_range)
 static starpu_ssize_t copy_file_range(int fd_in, loff_t *off_in, int fd_out,
 				      loff_t *off_out, size_t len, unsigned int flags)
 {
@@ -70,8 +70,8 @@ static unsigned starpu_unistd_opened_files;
 LIST_TYPE(starpu_unistd_work_copy,
 	int fd_src;
 	int fd_dst;
-	loff_t off_src;
-	loff_t off_dst;
+	starpu_loff_t off_src;
+	starpu_loff_t off_dst;
 	struct starpu_unistd_global_obj * obj_src;
 	struct starpu_unistd_global_obj * obj_dst;
 	size_t len;
@@ -537,7 +537,7 @@ int starpu_unistd_global_full_write(void *base STARPU_ATTRIBUTE_UNUSED, void *ob
 	return starpu_unistd_global_write(base, obj, ptr, 0, size);
 }
 
-#if HAVE_AIO_H
+#if defined(HAVE_AIO_H)
 void * starpu_unistd_global_async_full_read (void * base, void * obj, void ** ptr, size_t * size, unsigned dst_node)
 {
         struct starpu_unistd_global_obj *tmp = (struct starpu_unistd_global_obj *) obj;
@@ -857,17 +857,20 @@ void starpu_unistd_global_wait_request(void *async_channel)
 			}
 #elif defined(HAVE_AIO_H)
 			struct starpu_unistd_aiocb *starpu_aiocb = &event->event.event_aiocb;
-			const struct aiocb *aiocb = &starpu_aiocb->aiocb;
+			struct aiocb *aiocb = &starpu_aiocb->aiocb;
 			int values = -1;
 			int ret, myerrno = EAGAIN;
+			starpu_ssize_t size;
 			while(values < 0 && (myerrno == EAGAIN || myerrno == EINTR))
 			{
 				/* Wait the answer of the request TIMESTAMP IS NULL */
-				values = aio_suspend(&aiocb, 1, NULL);
+				values = aio_suspend((const struct aiocb **) &aiocb, 1, NULL);
 				myerrno = errno;
 			}
 			ret = aio_error(aiocb);
 			STARPU_ASSERT_MSG(!ret, "aio_error returned %d", ret);
+			size = aio_return(aiocb);
+			STARPU_ASSERT(size == (starpu_ssize_t) aiocb->aio_nbytes);
 #endif
 			break;
 		}
@@ -928,22 +931,27 @@ int starpu_unistd_global_test_request(void *async_channel)
 			return 0;
 #elif defined(HAVE_AIO_H)
 			struct starpu_unistd_aiocb *starpu_aiocb = &event->event.event_aiocb;
-			const struct aiocb *aiocb = &starpu_aiocb->aiocb;
+			struct aiocb *aiocb = &starpu_aiocb->aiocb;
 			int ret;
 
 #if defined(__GLIBC__) && (__GLIBC__ < 2 || (__GLIBC__ == 2 && __GLIBC_MINOR__ < 22))
 			/* glibc's aio_error was not threadsafe before glibc 2.22 */
 			struct timespec ts = { .tv_sec = 0, .tv_nsec = 0 };
-			ret = aio_suspend(&aiocb, 1, &ts);
+			ret = aio_suspend((const struct aiocb **) &aiocb, 1, &ts);
 			if (ret < 0 && (errno == EAGAIN || errno == EINTR))
 				return 0;
 			STARPU_ASSERT_MSG(!ret, "aio_suspend returned %d %d\n", ret, errno);
 #endif
+			starpu_ssize_t size;
 			/* Test the answer of the request */
 			ret = aio_error(aiocb);
 			if (ret == 0)
+			{
 				/* request is finished */
+				size = aio_return(aiocb);
+				STARPU_ASSERT(size == (starpu_ssize_t) aiocb->aio_nbytes);
 				return 1;
+			}
 			if (ret == EINTR || ret == EINPROGRESS || ret == EAGAIN)
 				return 0;
 			/* an error occured */
@@ -985,7 +993,6 @@ void starpu_unistd_global_free_request(void *async_channel)
 			struct aiocb *aiocb = &starpu_aiocb->aiocb;
 			if (starpu_aiocb->obj->descriptor < 0)
 				_starpu_unistd_reclose(aiocb->aio_fildes);
-			aio_return(aiocb);
 			free(event);
 #endif
 			break;
