@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2022  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  * Copyright (C) 2013       Corentin Salingue
  *
  * StarPU is free software; you can redistribute it and/or modify
@@ -766,7 +766,7 @@ static void benchmark_all_gpu_devices(void)
 #ifdef STARPU_HAVE_HWLOC
 	hwloc_bitmap_t former_cpuset = hwloc_bitmap_alloc();
 	hwloc_get_cpubind(hwtopology, former_cpuset, HWLOC_CPUBIND_THREAD);
-#elif __linux__
+#elif defined(__linux__)
 	/* Save the current cpu binding */
 	cpu_set_t former_process_affinity;
 	int ret;
@@ -845,7 +845,7 @@ static void benchmark_all_gpu_devices(void)
 #ifdef STARPU_HAVE_HWLOC
 	hwloc_set_cpubind(hwtopology, former_cpuset, HWLOC_CPUBIND_THREAD);
 	hwloc_bitmap_free(former_cpuset);
-#elif __linux__
+#elif defined(__linux__)
 	/* Restore the former affinity */
 	ret = sched_setaffinity(0, sizeof(former_process_affinity), &former_process_affinity);
 	if (ret)
@@ -971,7 +971,7 @@ static void write_bus_affinity_file_content(void)
 
 	_STARPU_DEBUG("writing affinities to %s\n", path);
 
-	f = fopen(path, "w+");
+	f = fopen(path, "a+");
 	if (!f)
 	{
 		perror("fopen write_buf_affinity_file_content");
@@ -980,7 +980,10 @@ static void write_bus_affinity_file_content(void)
 		STARPU_ABORT();
 	}
 
-	locked = _starpu_frdlock(f) == 0;
+	locked = _starpu_fwrlock(f) == 0;
+	fseek(f, 0, SEEK_SET);
+	_starpu_fftruncate(f, 0);
+
 	unsigned numa;
 	unsigned gpu;
 
@@ -3127,13 +3130,16 @@ void _starpu_load_bus_performance_files(void)
 
 	struct _starpu_machine_config * config = _starpu_get_machine_config();
 	nnumas = _starpu_topology_get_nnumanodes(config);
-#if defined(STARPU_USE_CUDA) || defined(STARPU_USE_SIMGRID)
+#ifndef STARPU_SIMGRID
+	ncpus = _starpu_topology_get_nhwcpu(config);
+#endif
+#if defined(STARPU_USE_CUDA) || defined(STARPU_SIMGRID)
 	ncuda = _starpu_get_cuda_device_count();
 #endif
-#if defined(STARPU_USE_OPENCL) || defined(STARPU_USE_SIMGRID)
+#if defined(STARPU_USE_OPENCL) || defined(STARPU_SIMGRID)
 	nopencl = _starpu_opencl_get_device_count();
 #endif
-#if defined(STARPU_USE_MPI_MASTER_SLAVE) || defined(STARPU_USE_SIMGRID)
+#if defined(STARPU_USE_MPI_MASTER_SLAVE)
 	nmpi_ms = _starpu_mpi_src_get_device_count();
 #endif
 #if defined(STARPU_USE_MIC) || defined(STARPU_USE_SIMGRID)
