@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2012-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2012-2022  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  * Copyright (C) 2013       Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
@@ -32,16 +32,23 @@
 #ifdef HAVE_GETRLIMIT
 #include <sys/resource.h>
 #endif
+#if (defined(HAVE_MSG_PROCESS_ATTACH) || defined(MSG_process_attach) || defined(HAVE_SG_ACTOR_ATTACH)) \
+	&& !defined(HAVE_SIMGRID_SET_MAESTRO)
 #include <simgrid/simix.h>
+#endif
 #ifdef STARPU_HAVE_SIMGRID_HOST_H
 #include <simgrid/host.h>
 #endif
+#ifdef STARPU_HAVE_SIMGRID_LINK_H
+#include <simgrid/link.h>
+#endif
 #ifdef STARPU_HAVE_SIMGRID_ENGINE_H
 #include <simgrid/engine.h>
 #endif
 #ifdef STARPU_HAVE_XBT_CONFIG_H
 #include <xbt/config.h>
 #endif
+#include <xbt/asserts.h>
 #include <smpi/smpi.h>
 
 #pragma weak starpu_main
@@ -288,6 +295,7 @@ starpu_sg_host_t _starpu_simgrid_get_host_by_worker(struct _starpu_worker *worke
 	return host;
 }
 
+#ifdef STARPU_USE_MPI
 /* Simgrid up to 3.15 would rename main into smpi_simulated_main_, and call that
  * from SMPI initialization
  * In case the MPI application didn't use smpicc to build the file containing
@@ -303,6 +311,7 @@ int _starpu_smpi_simulated_main_(int argc, char *argv[])
 	return starpu_main(argc, argv);
 }
 int smpi_simulated_main_(int argc, char *argv[]) __attribute__((weak, alias("_starpu_smpi_simulated_main_")));
+#endif
 
 /* This is used to start a non-MPI simgrid environment */
 void _starpu_start_simgrid(int *argc, char **argv)
@@ -371,7 +380,7 @@ void _starpu_start_simgrid(int *argc, char **argv)
 
 static int main_ret;
 
-int do_starpu_main(int argc, char *argv[])
+static int do_starpu_main(int argc, char *argv[])
 {
 	/* FIXME: Ugly work-around for bug in simgrid: the MPI context is not properly set at MSG process startup */
 	starpu_sleep(0.000001);
@@ -786,7 +795,7 @@ void _starpu_simgrid_submit_job(int workerid, struct _starpu_job *j, struct star
 		*finished = 0;
 		task->next = NULL;
 		/* Sleep 10µs for the GPU task queueing */
-		if (_starpu_simgrid_queue_malloc_cost())
+		if (_starpu_simgrid_cuda_queue_cost())
 			starpu_sleep(0.000010);
 		if (w->last_task)
 		{
@@ -833,7 +842,7 @@ LIST_TYPE(transfer,
 	struct transfer *next;
 )
 
-struct transfer_list pending;
+static struct transfer_list pending;
 
 /* Tell for two transfers whether they should be handled in sequence */
 static int transfers_are_sequential(struct transfer *new_transfer, struct transfer *old_transfer)
@@ -1167,7 +1176,7 @@ int _starpu_simgrid_transfer(size_t size, unsigned src_node, unsigned dst_node,
 		starpu_interface_start_driver_copy_async(src_node, dst_node, &start);
 
 	/* Sleep 10µs for the GPU transfer queueing */
-	if (_starpu_simgrid_queue_malloc_cost())
+	if (_starpu_simgrid_cuda_queue_cost())
 		starpu_sleep(0.000010);
 	transfer_submit(transfer);
 	/* Note: from here, transfer might be already freed */
@@ -1273,8 +1282,8 @@ void _starpu_simgrid_count_ngpus(void)
 		{
 			int busid;
 			starpu_sg_host_t srchost, dsthost;
-			xbt_dynar_t route_dynar = xbt_dynar_new(sizeof(SD_link_t), NULL);
-			SD_link_t link;
+			xbt_dynar_t route_dynar = xbt_dynar_new(sizeof(starpu_sg_link_t), NULL);
+			starpu_sg_link_t link;
 			int i, routesize;
 			int through;
 			unsigned src2;
@@ -1297,7 +1306,7 @@ void _starpu_simgrid_count_ngpus(void)
 #endif
 			routesize = xbt_dynar_length(route_dynar);
 #else
-			const SD_link_t *route = SD_route_get_list(srchost, dsthost);
+			const starpu_sg_link_t *route = SD_route_get_list(srchost, dsthost);
 			routesize = SD_route_get_size(srchost, dsthost);
 			for (i = 0; i < routesize; i++)
 				xbt_dynar_push(route_dynar, &route[i]);
@@ -1373,7 +1382,7 @@ void _starpu_simgrid_count_ngpus(void)
 
 				starpu_sg_host_t srchost2 = _starpu_simgrid_get_memnode_host(src2);
 				int routesize2;
-				xbt_dynar_t route_dynar2 = xbt_dynar_new(sizeof(SD_link_t), NULL);
+				xbt_dynar_t route_dynar2 = xbt_dynar_new(sizeof(starpu_sg_link_t), NULL);
 #if defined(HAVE_SG_HOST_GET_ROUTE) || defined(HAVE_SG_HOST_ROUTE) || defined(sg_host_route)
 #ifdef HAVE_SG_HOST_GET_ROUTE
 				sg_host_get_route(srchost2, ramhost, route_dynar2);
@@ -1382,7 +1391,7 @@ void _starpu_simgrid_count_ngpus(void)
 #endif
 				routesize2 = xbt_dynar_length(route_dynar2);
 #else
-				const SD_link_t *route2 = SD_route_get_list(srchost2, ramhost);
+				const starpu_sg_link_t *route2 = SD_route_get_list(srchost2, ramhost);
 				routesize2 = SD_route_get_size(srchost2, ramhost);
 				for (i = 0; i < routesize2; i++)
 					xbt_dynar_push(route_dynar2, &route2[i]);
