@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2008-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  * Copyright (C) 2013       Thibaut Lambert
  * Copyright (C) 2016       Uppsala University
  *
@@ -138,6 +138,7 @@ LIST_TYPE(_starpu_worker,
 #endif
 
 	struct timespec cl_start; /**< Codelet start time of the task currently running */
+	struct timespec cl_expend; /**< Codelet expected end time of the task currently running */
 	struct timespec cl_end; /**< Codelet end time of the last task running */
 	unsigned char first_task; /**< Index of first task in the pipeline */
 	unsigned char ntasks; /**< number of tasks in the pipeline */
@@ -321,6 +322,12 @@ struct _starpu_machine_topology
 	 */
 	unsigned workers_bindid[STARPU_NMAXWORKERS];
 
+	/** Indicates how many different values there are in
+	 * _starpu_machine_topology::workers_bindid, i.e. the length of the
+	 * cycle of the values there.
+	 */
+	unsigned workers_nbindid;
+
 	/** Indicates the successive CUDA identifier that should be
 	 * used by the CUDA driver.  It is either filled according to
 	 * the user's explicit parameters (from starpu_conf) or
