@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  * Copyright (C) 2018       Federal University of Rio Grande do Sul (UFRGS)
  *
  * StarPU is free software; you can redistribute it and/or modify
@@ -149,6 +149,15 @@ static int _starpu_malloc_should_pin(int flags)
 	return 0;
 }
 
+int _starpu_malloc_willpin_on_node(unsigned dst_node)
+{
+	int flags = malloc_on_node_default_flags[dst_node];
+	return (_starpu_malloc_should_pin(flags) && STARPU_RUNNING_ON_VALGRIND == 0
+			&& (_starpu_can_submit_cuda_task()
+			    /* || _starpu_can_submit_opencl_task() */
+			));
+}
+
 int _starpu_malloc_flags_on_node(unsigned dst_node, void **A, size_t dim, int flags)
 {
 	int ret=0;
@@ -185,6 +194,7 @@ int _starpu_malloc_flags_on_node(unsigned dst_node, void **A, size_t dim, int fl
 		goto end;
 	}
 
+	/* Note: synchronize this test with _starpu_malloc_willpin_on_node */
 	if (_starpu_malloc_should_pin(flags) && STARPU_RUNNING_ON_VALGRIND == 0)
 	{
 		if (_starpu_can_submit_cuda_task())
@@ -762,6 +772,8 @@ starpu_malloc_on_node_flags(unsigned dst_node, size_t size, int flags)
 
 	/* Round up allocation to block size */
 	int nblocks = (size + CHUNK_ALLOC_MIN - 1) / CHUNK_ALLOC_MIN;
+	if (!nblocks)
+		nblocks = 1;
 
 	struct _starpu_chunk *chunk;
 	int prevblock, block;
@@ -865,6 +877,8 @@ starpu_free_on_node_flags(unsigned dst_node, uintptr_t addr, size_t size, int fl
 
 	/* Round up allocation to block size */
 	int nblocks = (size + CHUNK_ALLOC_MIN - 1) / CHUNK_ALLOC_MIN;
+	if (!nblocks)
+		nblocks = 1;
 
 	STARPU_PTHREAD_MUTEX_LOCK(&chunk_mutex[dst_node]);
 	for (chunk = _starpu_chunk_list_begin(&chunks[dst_node]);
