@@ -293,7 +293,7 @@ void _starpu_fxt_write_paje_header(FILE *file STARPU_ATTRIBUTE_UNUSED, struct st
 	/* Types for the Worker of the Memory Node */
 	poti_DefineEventType("user_event", "P", "user event type");
 	poti_DefineEventType("thread_event", "T", "thread event type");
-	poti_DefineVariableType("gf", "W", "GFlops", "0 0 0");
+	poti_DefineVariableType("gf", "W", "GFlop/s", "0 0 0");
 	poti_DefineStateType("S", "T", "Thread State");
 	poti_DefineEntityValue("I", "S", "Idle", ".9 .1 0");
 	poti_DefineEntityValue("In", "S", "Initializing", "0.0 .7 1.0");
@@ -394,7 +394,7 @@ void _starpu_fxt_write_paje_header(FILE *file STARPU_ATTRIBUTE_UNUSED, struct st
 	/* Types for the Scheduler */
 	poti_DefineVariableType("nsubmitted", "Sc", "Number of Submitted Uncompleted Tasks", "0 0 0");
 	poti_DefineVariableType("nready", "Sc", "Number of Ready Tasks", "0 0 0");
-	poti_DefineVariableType("gft", "Sc", "Total GFlops", "0 0 0");
+	poti_DefineVariableType("gft", "Sc", "Total GFlop/s", "0 0 0");
 
 	/* Link types */
 	poti_DefineLinkType("MPIL", "MPIP", "MPICt", "MPICt", "MPI communication");
@@ -451,13 +451,13 @@ void _starpu_fxt_write_paje_header(FILE *file STARPU_ATTRIBUTE_UNUSED, struct st
 3       MS       Mm       \"Memory Node State\"                        \n\
 4       nsubmitted    Sc       \"Number of Submitted Uncompleted Tasks\"                        \n\
 4       nready    Sc       \"Number of Ready Tasks\"                        \n\
-4       gft    Sc       \"Total GFlops\"                        \n\
+4       gft    Sc       \"Total GFlop/s\"                        \n\
 4       use     Mm       \"Used (MB)\"                        \n\
 4       bwi_mm     Mm       \"Bandwidth In (MB/s)\"                        \n\
 4       bwo_mm     Mm       \"Bandwidth Out (MB/s)\"                        \n\
 4       bwi_mpi     MPICt       \"Bandwidth In (MB/s)\"                        \n\
 4       bwo_mpi     MPICt       \"Bandwidth Out (MB/s)\"                        \n\
-4       gf      W       \"GFlops\"                        \n\
+4       gf      W       \"GFlop/s\"                        \n\
 6       I       S       Idle         \".9 .1 .0\"		\n\
 6       In       S      Initializing       \"0.0 .7 1.0\"            \n\
 6       D       S      Deinitializing       \"0.0 .1 .7\"            \n\
