@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010, 2011, 2012, 2013, 2015  CNRS
- * Copyright (C) 2011, 2012  INRIA
+ * Copyright (C) 2010-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -14,7 +13,7 @@
  *
  * See the GNU Lesser General Public License in COPYING.LGPL for more details.
  */
-#include <config.h>
+
 #include <starpu.h>
 #include "../test_interfaces.h"
 #include "../../../helper.h"
@@ -31,7 +30,7 @@
  *
  * nzval  = [0, 1, 2, 3] ++ [4, 5, 6, 7] ++ [8, 9, 10, 11]
  * colind = [0, 0, 1]
- * rowptr = [0, 1 ]
+ * rowptr = [0, 1, 3 ]
  * r = c = 2
  */
 
@@ -42,6 +41,8 @@
 #define NNZ_BLOCKS     3   /* out of 4 */
 #define NZVAL_SIZE     (R*C*NNZ_BLOCKS)
 
+#define NROWS          2
+
 #ifdef STARPU_USE_CPU
 void test_bcsr_cpu_func(void *buffers[], void *args);
 #endif /* !STARPU_USE_CPU */
@@ -55,17 +56,17 @@ extern void test_bcsr_opencl_func(void *buffers[], void *args);
 
 static int nzval[NZVAL_SIZE]  =
 {
-	0, 1, 2, 3,    /* Fisrt block  */
+	0, 1, 2, 3,    /* First block  */
 	4, 5, 6, 7,    /* Second block */
 	8, 9, 10, 11   /* Third block  */
 };
 static int nzval2[NZVAL_SIZE];
 
-static uint32_t colind[NNZ_BLOCKS] = { 0, 0, 2 };
+static uint32_t colind[NNZ_BLOCKS] = { 0, 0, 1 };
 static uint32_t colind2[NNZ_BLOCKS];
 
-static uint32_t rowptr[2] = { 0, 1 };
-static uint32_t rowptr2[2];
+static uint32_t rowptr[NROWS+1] = { 0, 1, NNZ_BLOCKS };
+static uint32_t rowptr2[NROWS+1] = { 0, 0, NNZ_BLOCKS };
 
 static starpu_data_handle_t bcsr_handle;
 static starpu_data_handle_t bcsr2_handle;
@@ -97,7 +98,7 @@ register_data(void)
 	starpu_bcsr_data_register(&bcsr_handle,
 				  STARPU_MAIN_RAM,
 				  NNZ_BLOCKS,
-				  1, /* nrow */
+				  NROWS,
 				  (uintptr_t) nzval,
 				  colind,
 				  rowptr,
@@ -109,7 +110,7 @@ register_data(void)
 	starpu_bcsr_data_register(&bcsr2_handle,
 				  STARPU_MAIN_RAM,
 				  NNZ_BLOCKS,
-				  1, /* nrow */
+				  NROWS,
 				  (uintptr_t) nzval2,
 				  colind2,
 				  rowptr2,
@@ -177,7 +178,7 @@ test_bcsr_cpu_func(void *buffers[], void *args)
 int
 main(int argc, char **argv)
 {
-	data_interface_test_summary *summary;
+	struct data_interface_test_summary summary;
 	struct starpu_conf conf;
 	starpu_conf_init(&conf);
 
@@ -190,15 +191,13 @@ main(int argc, char **argv)
 
 	register_data();
 
-	summary = run_tests(&bcsr_config);
-	if (!summary)
-		exit(EXIT_FAILURE);
+	run_tests(&bcsr_config, &summary);
 
 	unregister_data();
 
 	starpu_shutdown();
 
-	data_interface_test_summary_print(stderr, summary);
+	data_interface_test_summary_print(stderr, &summary);
 
-	return data_interface_test_summary_success(summary);
+	return data_interface_test_summary_success(&summary);
 }
