@@ -1,7 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2017                                     CNRS
- * Copyright (C) 2016                                     Université de Bordeaux
+ * Copyright (C) 2016-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -30,9 +29,13 @@
 #include <starpu.h>
 #include "../helper.h"
 
+#ifdef STARPU_USE_FXT
+#define N 5
+#define ITER 5
+#else
 #define N 50
-
 #define ITER 50
+#endif
 
 int task_worker[N][ITER];
 int worker_task[STARPU_NMAXWORKERS][N*ITER];
