@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2018-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2018-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -71,8 +71,6 @@ int main(void)
 	struct starpu_task *task, *task2;
 
 	starpu_conf_init(&conf);
-	conf.nmic = 0;
-	conf.nmpi_ms = 0;
 
         ret = starpu_init(&conf);
 	if (STARPU_UNLIKELY(ret == -ENODEV))
@@ -81,7 +79,7 @@ int main(void)
 	}
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_init");
 
-	if (starpu_cpu_worker_get_count() < 1)
+	if (starpu_cpu_worker_get_count() < 1 && starpu_mpi_ms_worker_get_count() < 1)
 	{
 		FPRINTF(stderr, "This application requires at least 1 cpu worker\n");
 		starpu_shutdown();
